.. include:: ../README.rst

HTTP API Helpers
================
.. autoclass:: vetoes.service.HTTPServiceMixin
   :members:

Configuration Related
=====================
.. autoclass:: vetoes.config.FeatureFlagMixin
   :members:

.. autoclass:: vetoes.config.TimeoutConfigurationMixin
   :members:

Release History
===============

`0.1.0`_ (06-Jan-2017)
----------------------
- Initial release including :class:`vetoes.service.HTTPServiceMixin`,
  :class:`vetoes.config.FeatureFlagMixin`, and
  :class:`vetoes.config.TimeoutConfigurationMixin`

.. _Next Release: https://github.aweber.io/edeliv/vetoes/compare/0.0.0...HEAD
.. _0.1.0: https://github.aweber.io/edeliv/vetoes/compare/0.0.0...0.1.0
